From 7eef033e580ac34d45fc0788e4ff05cf1dc4a977 Mon Sep 17 00:00:00 2001
From: Lucas D Hedding <lucashedding@1463982.no-reply.drupal.org>
Date: Tue, 28 May 2013 14:00:28 -0500
Subject: [PATCH] Issue #2003330 by heddn | ericthelast | Dan Reinders: Rename
 Views method render_items() to renderItems().

---
 core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php   |    4 ++--
 .../views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php  |    2 +-
 .../views/lib/Drupal/views/Plugin/views/field/PrerenderList.php    |    4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
index bc8dfff..050a99a 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
@@ -1142,7 +1142,7 @@ function advanced_render($values) {
           $items[] = $this->render_text($alter);
         }
 
-        $value = $this->render_items($items);
+        $value = $this->renderItems($items);
       }
       else {
         $alter = array('phase' => VIEWS_HANDLER_RENDER_TEXT_PHASE_COMPLETELY) + $this->options['alter'];
diff --git a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
index aa364ab..acfd47c 100644
--- a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
+++ b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
@@ -25,7 +25,7 @@
 class Field extends FieldPluginBase {
 
   /**
    * An array to store field renderable arrays for use by render_items.
    *
    * @var array
    */
@@ -620,7 +620,7 @@ public function submitGroupByForm(&$form, &$form_state) {
    * When using advanced render, each possible item in the list is rendered
    * individually. Then the items are all pasted together.
    */
-  function render_items($items) {
+  function renderItems($items) {
     if (!empty($items)) {
       if (!$this->options['group_rows']) {
         return implode('', $items);
@@ -25,7 +25,7 @@
 
   /**
-   * An array to store field renderable arrays for use by render_items.
+   * An array to store field renderable arrays for use by renderItems.
    *
    * @var array
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php
index 1dfa85b..9986048 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php
@@ -73,7 +73,7 @@ public function buildOptionsForm(&$form, &$form_state) {
    * When using advanced render, each possible item in the list is rendered
    * individually. Then the items are all pasted together.
    */
-  function render_items($items) {
+  function renderItems($items) {
     if (!empty($items)) {
       if ($this->options['type'] == 'separator') {
         return implode($this->sanitizeValue($this->options['separator'], 'xss_admin'), $items);
@@ -112,7 +112,7 @@ function get_items($values) {
    * Determine if advanced rendering is allowed.
    *
    * By default, advanced rendering will NOT be allowed if the class
    * inheriting from this does not implement a 'render_items' method.
    */
   function allow_advanced_render() {
     // Note that the advanced render bits also use the presence of
@@ -112,7 +112,7 @@ function get_items($values) {
    *
    * By default, advanced rendering will NOT be allowed if the class
-   * inheriting from this does not implement a 'render_items' method.
+   * inheriting from this does not implement a 'renderItems' method.
    */
   function allow_advanced_render() {
-- 
1.7.10.4

